==> node-rollup-plugin-buble_1.0.0+ds1+~0.19.8.orig.tar.xz: node-rollup-plugin-buble-1.0.0/packages/buble/CHANGELOG.md <==
# @rollup/plugin-buble ChangeLog

## v1.0.0

_2022-10-08_

### Breaking Changes

- fix: prepare for Rollup 3 [#1305](https://github.com/rollup/plugins/pull/1305)

### Updates

- chore: upgrade TypeScript [#710](https://github.com/rollup/plugins/pull/710)
- chore: update dependencies ([92d6c82](https://github.com/rollup/plugins/commit/92d6c8207db101fc82c6aeade0c49a2b9ee361e2))

## v0.21.3

_2020-04-12_

### Updates

- chore: upgrade buble, resolves babel/babel#11216 (#288)

## v0.21.2

_2020-04-12_

### Updates

- chore: Move to Typescript (#231)

## v0.21.1

_2020-02-01_

### Updates

- chore: update dependencies (579c612)
- chore: add missing entry to changelog (cbfbe98)

## 0.21.0

_2019-12-21_

- feat(buble): use types from @types/buble (#54)
- feat: export Rollup\*Options interfaces (#53)

## 0.20.0

- Republish under `@rollup` scope

## 0.19.8

- Update `buble`

## 0.19.6

- Update dependencies
- Add test
- Enable direct Github installation

## 0.19.4

- Update `buble`
- Add usage documentation
- Bump dev dependencies
- Update repository link

## 0.19.2

- Update `buble`

## 0.19.1

- Update `buble`

## 0.19.0

- Update `buble`
- Better support for errors thrown by `buble`

## 0.18.0

- Update `buble`

## 0.17.0

- Update `buble`

## 0.16.0

- Update `buble`

## 0.15.0

- Update `buble`

## 0.14.0

- Update `buble`

## 0.13.0

- Update `buble` and other deps

## 0.12.1

- Return a `name`

## 0.12.0

- Update `buble`

## 0.11.0

- Update `buble`

## 0.10.0

- Update `buble`

## 0.9.0

- Update `buble`

## 0.8.0

- Update `buble`

## 0.7.0

- Update `buble`

## 0.6.0

- Update `buble`

## 0.5.0

- Update `buble`

## 0.4.0

- Update `buble`

## 0.3.4

- Update `buble`

## 0.2.3

- Make plugin 0.12-friendly

## 0.2.2

- Update `buble`

## 0.1.0

- First release

==> node-rollup-plugin-buble_1.0.1+ds1+~0.19.8.orig.tar.xz: node-rollup-plugin-buble-1.0.1/packages/buble/CHANGELOG.md <==
# @rollup/plugin-buble ChangeLog

## v1.0.1

_2022-10-21_

### Updates

- chore: update rollup dependencies ([3038271](https://github.com/rollup/plugins/commit/303827191ede6b2e4eade96c6968ed16a587683f))

## v1.0.0

_2022-10-08_

### Breaking Changes

- fix: prepare for Rollup 3 [#1305](https://github.com/rollup/plugins/pull/1305)

### Updates

- chore: upgrade TypeScript [#710](https://github.com/rollup/plugins/pull/710)
- chore: update dependencies ([92d6c82](https://github.com/rollup/plugins/commit/92d6c8207db101fc82c6aeade0c49a2b9ee361e2))

## v0.21.3

_2020-04-12_

### Updates

- chore: upgrade buble, resolves babel/babel#11216 (#288)

## v0.21.2

_2020-04-12_

### Updates

- chore: Move to Typescript (#231)

## v0.21.1

_2020-02-01_

### Updates

- chore: update dependencies (579c612)
- chore: add missing entry to changelog (cbfbe98)

## 0.21.0

_2019-12-21_

- feat(buble): use types from @types/buble (#54)
- feat: export Rollup\*Options interfaces (#53)

## 0.20.0

- Republish under `@rollup` scope

## 0.19.8

- Update `buble`

## 0.19.6

- Update dependencies
- Add test
- Enable direct Github installation

## 0.19.4

- Update `buble`
- Add usage documentation
- Bump dev dependencies
- Update repository link

## 0.19.2

- Update `buble`

## 0.19.1

- Update `buble`

## 0.19.0

- Update `buble`
- Better support for errors thrown by `buble`

## 0.18.0

- Update `buble`

## 0.17.0

- Update `buble`

## 0.16.0

- Update `buble`

## 0.15.0

- Update `buble`

## 0.14.0

- Update `buble`

## 0.13.0

- Update `buble` and other deps

## 0.12.1

- Return a `name`

## 0.12.0

- Update `buble`

## 0.11.0

- Update `buble`

## 0.10.0

- Update `buble`

## 0.9.0

- Update `buble`

## 0.8.0

- Update `buble`

## 0.7.0

- Update `buble`

## 0.6.0

- Update `buble`

## 0.5.0

- Update `buble`

## 0.4.0

- Update `buble`

## 0.3.4

- Update `buble`

## 0.2.3

- Make plugin 0.12-friendly

## 0.2.2

- Update `buble`

## 0.1.0

- First release
